package com.ruoyi.hezhi.service;

import com.ruoyi.hezhi.domain.TbExpressKdCode;

import java.util.List;

/**
 * 快递编码Service接口
 *
 * @author ruoyi
 * @date 2024-11-20
 */
public interface ITbExpressKdCodeService
{
    /**
     * 查询快递编码
     *
     * @param id 快递编码主键
     * @return 快递编码
     */
    public TbExpressKdCode selectTbExpressKdCodeById(Long id);

    /**
     * 查询快递编码列表
     *
     * @param tbExpressKdCode 快递编码
     * @return 快递编码集合
     */
    public List<TbExpressKdCode> selectTbExpressKdCodeList(TbExpressKdCode tbExpressKdCode);

    /**
     * 新增快递编码
     *
     * @param tbExpressKdCode 快递编码
     * @return 结果
     */
    public int insertTbExpressKdCode(TbExpressKdCode tbExpressKdCode);

    /**
     * 修改快递编码
     *
     * @param tbExpressKdCode 快递编码
     * @return 结果
     */
    public int updateTbExpressKdCode(TbExpressKdCode tbExpressKdCode);

    /**
     * 批量删除快递编码
     *
     * @param ids 需要删除的快递编码主键集合
     * @return 结果
     */
    public int deleteTbExpressKdCodeByIds(Long[] ids);

    /**
     * 删除快递编码信息
     *
     * @param id 快递编码主键
     * @return 结果
     */
    public int deleteTbExpressKdCodeById(Long id);

    /**
     * 查询快递
     *
     * @param code 快递编码
     * @return 快递编码
     */
    public TbExpressKdCode selectTbExpressKdCodeByCode(String code);

    // /**
    //  * 查询快递信息
    //  *
    //  * @param shippingMark 快递公司代号
    //  * @param shippingCode 快递单号
    //  * @return 结果
    //  */
    // public List<Map<String,Object>> checkExpressInfoMessage(String shippingMark, String shippingCode);
}
